@@ -19,8 +19,9 @@ public:
 
 	std::unique_ptr<hdlAst::HdlModuleDec> visitEntity_declaration(
 			vhdlParser::Entity_declarationContext *ctx);
-	static void visitEntity_declarative_item(
-			vhdlParser::Entity_declarative_itemContext *ctx);
+	void visitEntity_declarative_item(
+			vhdlParser::Entity_declarative_itemContext *ctx,
+			std::vector<std::unique_ptr<hdlAst::iHdlObj>> &objs);
 	static void visitGeneric_clause(vhdlParser::Generic_clauseContext *ctx,
 			std::vector<std::unique_ptr<hdlAst::HdlIdDef>> &generics);
 	static void visitPort_clause(vhdlParser::Port_clauseContext *ctx,
